{ config, pkgs, system, inputs, lib, ... }:

{
  home.username = "regent";
  home.homeDirectory = "/home/regent";

  catppuccin = {
    enable = true;
    flavor = "mocha";
    accent = "rosewater";
    /*waybar = { doesnt work for some reason
      enable = true;
    };*/
    ghostty.enable = true;
    ghostty.flavor = "mocha";
    nvim.enable = true;
    nvim.flavor = "mocha";
  };

  programs.ghostty.enable = true;
  programs.ghostty.settings = {
    font-size = 24;
    theme = "catppuccin-mocha";
  };

  programs.neovim.enable = true;
  programs.neovim = {
    extraPackages = with pkgs; [
      lua-language-server
      stylua
      ripgrep
    ];

    plugins = with pkgs.vimPlugins; [
      lazy-nvim
    ];
  };

  home.pointerCursor = {
    gtk.enable = true;
    package = pkgs.phinger-cursors;
    name = "Phinger-cursors-light";
    size = 48;
  }; 

  programs.waybar = {
    enable = true;
    style =
''
@define-color rosewater #f5e0dc;
@define-color flamingo #f2cdcd;
@define-color pink #f5c2e7;
@define-color mauve #cba6f7;
@define-color red #f38ba8;
@define-color maroon #eba0ac;
@define-color peach #fab387;
@define-color yellow #f9e2af;
@define-color green #a6e3a1;
@define-color teal #94e2d5;
@define-color sky #89dceb;
@define-color sapphire #74c7ec;
@define-color blue #89b4fa;
@define-color lavender #b4befe;
@define-color text #cdd6f4;
@define-color subtext1 #bac2de;
@define-color subtext0 #a6adc8;
@define-color overlay2 #9399b2;
@define-color overlay1 #7f849c;
@define-color overlay0 #6c7086;
@define-color surface2 #585b70;
@define-color surface1 #45475a;
@define-color surface0 #313244;
@define-color base #1e1e2e;
@define-color mantle #181825;
@define-color crust #11111b;


* {
  font-family: 'Fira Code', monospace;
  font-size: 17px;
  min-height: 0;
}

window#waybar {
  padding: 0px;
  margin: 0px;
  border: 0px;
  /*background-color:rgb(0, 0, 0);*/
  background-color: @base;
  color: @text;
}

/*window#waybar.empty {
	background-color:rgba(255, 255, 255, 0);
}*/

#workspaces {
  border-radius: 1rem;
  margin: 5px;
  margin-left: 1rem;
  background-color: rgba(0, 0, 0, 0.21);
}

#workspaces button {
  color: @lavender;
  border-radius: 1rem;
  padding: 0.4rem;
}

#workspaces button.active {
  color: @sky;
  border-radius: 1rem;
  background-color: rgba(255, 255, 255, 0.5);
}

#workspaces button:hover {
  color: @sapphire;
  border-radius: 1rem;
}

#custom-music,
#tray,
#backlight,
#clock,
#battery,
#pulseaudio,
#custom-lock,
#custom-power {
  padding: 0.5rem 1rem;
  margin: 5px 0;
  color: @text;
}

#clock {
  color: @text;
  border-radius: 0px 1rem 1rem 0px;
  margin-right: 1rem;
}
'';
    settings = {
      mainBar = {
        layer = "top";
        position = "top";
        mod = "dock";
        exclusive = true;
        passthrough = false;
        #gtk-layer-shell = true;
        height = 0;
        output = [
          "HDMI-A-1"
          "DP-1"
        ];
        modules-left = [ 
          "sway/workspaces"
        ];
        modules-center = [ "sway/window" ];
        modules-right = [
          "pulseaudio"
          "clock"          
        ];

        "sway/workspaces" = {
          disable-scroll = true;
          sort-by-name = true;
        };
        tray = {
          icon-size = 13;
          tooltip = false;
          spacing = 10;
        };
        network = {
          format = "󰖩 {essid}";
          format-disconnected = "󰖪 disconnected";
        };
        clock = {
          format = " {:%I:%M %p   %m/%d} ";
          tooltip-format = ''
            <big>{:%Y %B}</big>
            <tt><small>{calendar}</small></tt>'';
        };

        pulseaudio = {
          format = "{icon} {volume}%";
          tooltip = false;
          format-muted = " Muted";
          on-click = "pamixer -t";
          on-scroll-up = "pamixer -i 5";
          on-scroll-down = "pamixer -d 5";
          scroll-step = 5;
          format-icons = {
            headphone = "";
            hands-free = "";
            headset = "";
            phone = "";
            portable = "";
            car = "";
            default = [ "" "" "" ];
          };
        };

        "pulseaudio#microphone" = {
          format = "{format_source}";
          tooltip = false;
          format-source = " {volume}%";
          format-source-muted = " Muted";
          on-click = "pamixer --default-source -t";
          on-scroll-up = "pamixer --default-source -i 5";
          on-scroll-down = "pamixer --default-source -d 5";
          scroll-step = 5;
        };
      };
    };
  };

  home.stateVersion = "25.05";
}